<?php
/**
 * Add theme dashboard page
 *
 * Get theme actions required
 *
 * @return array|mixed|void
 *
 * @package elixar
 */
function elixar_get_recommended_actions( ) {
    $actions = array();
    $front_page = get_option( 'page_on_front' );
    $actions['page_on_front'] = 'dismiss';
    $actions['page_template'] = 'dismiss';
    $actions['recommend_plugins'] = 'dismiss';
    if ( 'page' != get_option( 'show_on_front' ) ) {
        $front_page = 0;
    }
    if ( $front_page <= 0  ) {
        $actions['page_on_front'] = 'active';
        $actions['page_template'] = 'active';
    } else {
        if ( get_post_meta( $front_page, '_wp_page_template', true ) == 'home-page.php' ) {
            $actions['page_template'] = 'dismiss';
        } else {
            $actions['page_template'] = 'active';
        }
    }
    $recommend_plugins = get_theme_support( 'recommend-plugins' );
    if ( is_array( $recommend_plugins ) && isset( $recommend_plugins[0] ) ){
        $recommend_plugins = $recommend_plugins[0];
    } else {
        $recommend_plugins[] = array();
    }
    if ( ! empty( $recommend_plugins ) ) {
        foreach ( $recommend_plugins as $plugin_slug => $plugin_info ) {
            $plugin_info = wp_parse_args( $plugin_info, array(
                'name' => '',
                'active_filename' => '',
            ) );
            if ( $plugin_info['active_filename'] ) {
                $active_file_name = $plugin_info['active_filename'] ;
            } else {
                $active_file_name = $plugin_slug . '/' . $plugin_slug . '.php';
            }
            if ( ! is_plugin_active( $active_file_name ) ) {
                $actions['recommend_plugins'] = 'active';
            }
        }
    }
    $actions = apply_filters( 'elixar_get_recommended_actions', $actions );
    $hide_by_click = get_option( 'elixar_actions_dismiss' );
    if ( ! is_array( $hide_by_click ) ) {
        $hide_by_click = array();
    }
    $n_active  = $n_dismiss = 0;
    $number_notice = 0;
    foreach ( $actions as $k => $v ) {
        if ( ! isset( $hide_by_click[ $k ] ) ) {
            $hide_by_click[ $k ] = false;
        }
        if ( $v == 'active' ) {
            $n_active ++ ;
            $number_notice ++ ;
            if ( $hide_by_click[ $k ] ) {
                if ( $hide_by_click[ $k ] == 'hide' ) {
                    $number_notice -- ;
                }
            }
        } else if ( $v == 'dismiss' ) {
            $n_dismiss ++ ;
        }
    }
    $elixar_return = array(
        'actions' => $actions,
        'number_actions' => count( $actions ),
        'number_active' => $n_active,
        'number_dismiss' => $n_dismiss,
        'hide_by_click'  => $hide_by_click,
        'number_notice'  => $number_notice,
    );
    if ( $elixar_return['number_notice'] < 0 ) {
        $elixar_return['number_notice'] = 0;
    }
    return $elixar_return;
}
add_action('switch_theme', 'elixar_reset_recommended_actions');
function elixar_reset_recommended_actions () {
    delete_option('elixar_actions_dismiss');
}
if ( ! function_exists( 'elixar_admin_scripts' ) ) :
    /**
     * Enqueue scripts for admin page only: Theme info page
     */
    function elixar_admin_scripts( $hook ) {
        if ( $hook === 'widgets.php' || $hook === 'appearance_page_ft_elixar'  ) {
            wp_enqueue_style( 'elixar-admin-css', get_template_directory_uri() . '/css/customizer_css/css/elixar-admin.css' );
            // Add recommend plugin css
            wp_enqueue_style( 'plugin-install' );
            wp_enqueue_script( 'plugin-install' );
            wp_enqueue_script( 'updates' );
            add_thickbox();
        }
		 wp_enqueue_style( 'elixar-admincss', get_template_directory_uri() . '/css/elixar-admin.css' );
    }
endif;
add_action( 'admin_enqueue_scripts', 'elixar_admin_scripts' );
add_action('admin_menu', 'elixar_theme_info');
function elixar_theme_info() {
    $actions = elixar_get_recommended_actions();
    $number_count = $actions['number_notice'];
    if ( $number_count > 0 ){
        /* translators: %s: Update Label Text */
		$update_label = sprintf( _n( '%1$s action required', '%1$s actions required', $number_count, 'elixar' ), $number_count );
        $count = "<span class='update-plugins count-".esc_attr( $number_count )."' title='".esc_attr( $update_label )."'><span class='update-count'>" . number_format_i18n($number_count) . "</span></span>";
        /* translators: %s: Menu Title */
		$menu_title = sprintf( esc_html__('Elixar Theme %s', 'elixar'), $count );
    } else {
        $menu_title = esc_html__('Elixar Theme', 'elixar');
    }
    add_theme_page( esc_html__( 'Elixar Dashboard', 'elixar' ), $menu_title, 'edit_theme_options', 'ft_elixar', 'elixar_theme_info_page');
}
/**
 * Add admin notice when active theme, just show one timetruongsa@200811
 *
 * @return bool|null
 */
function elixar_admin_notice() {
    if ( ! function_exists( 'elixar_get_recommended_actions' ) ) {
        return false;
    }
    $actions = elixar_get_recommended_actions();
    $number_action = $actions['number_notice'];
    if ( $number_action > 0 ) {
        $theme_data = wp_get_theme();
        ?>
        <div class="updated notice notice-success notice-alt is-dismissible">
            <p><?php /* translators: %s: Welcome Page Notice */
			printf( esc_html__( 'Welcome! Thank you for choosing %1$s! To fully take advantage of the best our theme can offer please make sure you visit our %2$s Welcome page %3$s', 'elixar' ),  esc_html( $theme_data->Name ), '<a href="'. esc_url(admin_url( 'themes.php?page=ft_elixar' )).'">', '</a>' ); ?></p>
        </div>
        <?php
    }
}
function elixar_admin_import_notice(){
    ?>
    <div class="updated notice notice-success notice-alt is-dismissible">
        <p><?php /* translators: %s: Import Data Info */
		printf( esc_html__( 'Save time by import our demo data, your website will be set up and ready to customize in minutes. %s', 'elixar' ), '<a class="button button-secondary" href="'.esc_url( add_query_arg( array( 'page' => 'ft_elixar&tab=demo-data-importer' ), admin_url( 'themes.php' ) ) ).'">'.esc_html__( 'Import Demo Data', 'elixar' ).'</a>' ); ?></p>
    </div>
    <?php
}
function elixar_one_activation_admin_notice(){
    global $pagenow;
    if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
        add_action( 'admin_notices', 'elixar_admin_notice' );
        add_action( 'admin_notices', 'elixar_admin_import_notice' );
    }
}
function elixar_render_recommend_plugins( $recommend_plugins = array() ){
    foreach ( $recommend_plugins as $plugin_slug => $plugin_info ) {
        $plugin_info = wp_parse_args( $plugin_info, array(
            'name' => '',
            'active_filename' => '',
        ) );
        $plugin_name = $plugin_info['name'];
        $status = is_dir( WP_PLUGIN_DIR . '/' . $plugin_slug );
        $button_class = 'install-now button';
        if ( $plugin_info['active_filename'] ) {
            $active_file_name = $plugin_info['active_filename'] ;
        } else {
            $active_file_name = $plugin_slug . '/' . $plugin_slug . '.php';
        }
        if ( ! is_plugin_active( $active_file_name ) ) {
            $button_txt = esc_html__( 'Install Now', 'elixar' );
            if ( ! $status ) {
                $install_url = wp_nonce_url(
                    add_query_arg(
                        array(
                            'action' => 'install-plugin',
                            'plugin' => $plugin_slug
                        ),
                        network_admin_url( 'update.php' )
                    ),
                    'install-plugin_'.$plugin_slug
                );
            } else {
                $install_url = add_query_arg(array(
                    'action' => 'activate',
                    'plugin' => rawurlencode( $active_file_name ),
                    'plugin_status' => 'all',
                    'paged' => '1',
                    '_wpnonce' => wp_create_nonce('activate-plugin_' . $active_file_name ),
                ), network_admin_url('plugins.php'));
                $button_class = 'activate-now button-primary';
                $button_txt = esc_html__( 'Active Now', 'elixar' );
            }
            $detail_link = add_query_arg(
                array(
                    'tab' => 'plugin-information',
                    'plugin' => $plugin_slug,
                    'TB_iframe' => 'true',
                    'width' => '772',
                    'height' => '349',
                ),
                network_admin_url( 'plugin-install.php' )
            );
            echo '<div class="rcp">';
            echo '<h4 class="rcp-name">';
            echo esc_html( $plugin_name );
            echo '</h4>';
            echo '<p class="action-btn plugin-card-'.esc_attr( $plugin_slug ).'"><a href="'. esc_url( $install_url ) .'" data-slug="'. esc_attr( $plugin_slug ) .'" class="'. esc_attr( $button_class ) .'">'. esc_html( $button_txt ) .'</a></p>';
            echo '<a class="plugin-detail thickbox open-plugin-details-modal" href="'. esc_url( $detail_link ) .'">'. esc_html__( 'Details', 'elixar' ) .'</a>';
            echo '</div>';
        }
    }
}
function elixar_admin_dismiss_actions(){
    // Action for dismiss
    if ( isset( $_GET['elixar_action_notice'] ) ) {
        $actions_dismiss =  get_option( 'elixar_actions_dismiss' );
        if ( ! is_array( $actions_dismiss ) ) {
            $actions_dismiss = array();
        }
        $action_key = sanitize_text_field( $_GET['elixar_action_notice'] );
        if ( isset( $actions_dismiss[ $action_key ] ) &&  $actions_dismiss[ $action_key ] == 'hide' ){
            $actions_dismiss[ $action_key ] = 'show';
        } else {
            $actions_dismiss[ $action_key ] = 'hide';
        }
        update_option( 'elixar_actions_dismiss', $actions_dismiss );
        $url = wp_unslash( $_SERVER['REQUEST_URI'] );
        $url = remove_query_arg( 'elixar_action_notice', $url );
        wp_redirect( $url );
        die();
    }
    // Action for copy options
    if ( isset( $_POST['copy_from'] ) && isset( $_POST['copy_to'] ) ) {
        $from = sanitize_text_field( $_POST['copy_from'] );
        $to = sanitize_text_field( $_POST['copy_to'] );
        if ( $from && $to ) {
            $mods = get_option("theme_mods_" . $from);
            update_option("theme_mods_" . $to, $mods);
            $url = wp_unslash( $_SERVER['REQUEST_URI'] );
            $url = add_query_arg(array('copied' => 1), $url);
            wp_redirect($url);
            die();
        }
    }
}
add_action( 'admin_init', 'elixar_admin_dismiss_actions' );
/* activation notice */
add_action( 'load-themes.php',  'elixar_one_activation_admin_notice'  );
function elixar_theme_info_page() {
    $theme_data = wp_get_theme('elixar');
    if ( isset( $_GET['elixar_action_dismiss'] ) ) {
        $actions_dismiss =  get_option( 'elixar_actions_dismiss' );
        if ( ! is_array( $actions_dismiss ) ) {
            $actions_dismiss = array();
        }
        $actions_dismiss[ sanitize_text_field( $_GET['elixar_action_dismiss'] ) ] = 'dismiss';
        update_option( 'elixar_actions_dismiss', $actions_dismiss );
    }
    // Check for current viewing tab
    $tab = null;
    if ( isset( $_GET['tab'] ) ) {
        $tab = sanitize_text_field( $_GET['tab'] );
    } else {
        $tab = null;
    }
    $actions_r = elixar_get_recommended_actions();
    $number_action = intval( $actions_r['number_notice'] );
    $actions = $actions_r['actions'];
    $current_action_link =  admin_url( 'themes.php?page=ft_elixar&tab=recommended_actions' );
    $recommend_plugins = get_theme_support( 'recommend-plugins' );
    if ( is_array( $recommend_plugins ) && isset( $recommend_plugins[0] ) ){
        $recommend_plugins = $recommend_plugins[0];
    } else {
        $recommend_plugins[] = array();
    }
    ?>
    <div class="wrap about-wrap theme_info_wrapper">
        <h1><?php /* translators: %s: Theme Version Info */
		printf(esc_html__('Welcome to Elixar - Version %1s', 'elixar'), floatval( $theme_data->Version ) ); ?></h1>
        <div class="about-text"><?php esc_html_e( 'Elixar is a creative and flexible WordPress theme well suited for business, portfolio, digital agency, product showcase, freelancers websites.', 'elixar' ); ?></div>
        <a target="_blank" href="<?php echo esc_url('https://www.webhuntinfotech.com/'); ?>" class="webhuntthemes-badge wp-badge"><span><?php echo esc_html('WebhuntThemes'); ?></span></a>
        <h2 class="nav-tab-wrapper">
            <a href="?page=ft_elixar" class="nav-tab<?php echo is_null($tab) ? ' nav-tab-active' : null; ?>"><?php esc_html_e( 'Elixar', 'elixar' ) ?></a>
            <a href="?page=ft_elixar&tab=recommended_actions" class="nav-tab<?php echo $tab == 'recommended_actions' ? ' nav-tab-active' : null; ?>"><?php esc_html_e( 'Recommended Actions', 'elixar' ); echo ( $number_action > 0 ) ? "<span class='theme-action-count'>".  intval($number_action) ."</span>" : ''; ?></a>
            <?php if ( ! class_exists('Elixar_Premium') ) { ?>
            <a href="?page=ft_elixar&tab=free_pro" class="nav-tab<?php echo $tab == 'free_pro' ? ' nav-tab-active' : null; ?>"><?php esc_html_e( 'Free vs Pro', 'elixar' ); ?></span></a>
            <?php } ?>
            <a href="?page=ft_elixar&tab=changelog-viewer" class="nav-tab<?php echo $tab == 'changelog-viewer' ? ' nav-tab-active' : null; ?>"><?php esc_html_e( 'Changelog', 'elixar' ); ?></span></a>
            <?php do_action( 'elixar_admin_more_tabs' ); ?>
        </h2>
        <?php if ( is_null( $tab ) ) { ?>
            <div class="theme_info info-tab-content">
                <div class="theme_info_column clearfix">
                    <div class="theme_info_left">
                        <div class="theme_link">
                            <h3><?php esc_html_e( 'Theme Customizer', 'elixar' ); ?></h3>
                            <p class="about"><?php /* translators: %s: Get Started */
							printf( esc_html__('%s supports the Theme Customizer for all theme settings. Click "Customize" to start customize your site.', 'elixar'), esc_html( $theme_data->Name ) ); ?></p>
                            <p>
                                <a href="<?php echo esc_url(admin_url('customize.php')); ?>" class="button button-primary"><?php esc_html_e('Start Customize', 'elixar'); ?></a>
                            </p>
                        </div>
                        <div class="theme_link">
                            <h3><?php esc_html_e( 'Theme Documentation', 'elixar' ); ?></h3>
                            <p class="about"><?php /* translators: %s: Documentation Info */
							printf(esc_html__('Need any help to setup and configure %s? Please have a look at our documentations instructions.', 'elixar'), esc_html( $theme_data->Name) ); ?></p>
                            <p>
                                <a href="<?php echo esc_url( 'https://www.webhuntinfotech.com/elixar-lite-documentation/' ); ?>" target="_blank" class="button button-primary"><?php esc_html_e('Elixar Documentation', 'elixar'); ?></a>
                            </p>
                            <?php do_action( 'elixar_dashboard_theme_links' ); ?>
                        </div>
						<div class="theme_link">
                            <h3><?php esc_html_e( 'Create a Child Theme', 'elixar' ); ?></h3>
                            <p class="about"><?php printf(esc_html__('If you want to make changes to the themes files, those changes are likely to be overwritten when you next update the theme. In order to prevent that from happening, you need to create a child theme. For this, please follow the documentation below.', 'elixar'), esc_html( $theme_data->Name )); ?></p>
                            <p>
                            <a href="<?php echo esc_url( 'https://demo.webhuntinfotech.com/blog/2016/01/11/how-to-create-a-child-theme/' ); ?>" target="_blank" class="button button-primary"><?php esc_html_e('View how to do this', 'elixar'); ?></a>
                            </p>
                        </div>
						<div class="theme_link">
                            <h3><?php esc_html_e( 'Gallery in Blog Posts', 'elixar' ); ?></h3>
                            <p class="about"><?php printf(esc_html__('If you want to use more than one images in your post or want to make gallery images in your post. This can be accomplished by following the documentation below.', 'elixar'), esc_html( $theme_data->Name )); ?></p>
                            <p>
                            <a href="<?php echo esc_url( 'https://demo.webhuntinfotech.com/blog/2016/01/11/add-gallery-posts-in-matrix-or-kyma-theme/' ); ?>" target="_blank" class="button button-primary"><?php esc_html_e('View how to do this', 'elixar'); ?></a>
                            </p>
                        </div>
                        <div class="theme_link">
                            <h3><?php esc_html_e( 'Having Trouble, Need Support?', 'elixar' ); ?></h3>
                            <p class="about"><?php /* translators: %s: Support Info */
							printf(esc_html__('Support for %s WordPress theme is conducted through WebhuntThemes support ticket system.', 'elixar'), esc_html( $theme_data->Name )); ?></p>
                            <p>
                                <a href="<?php echo esc_url('https://wordpress.org/themes/elixar/' ); ?>" target="_blank" class="button button-secondary"><?php echo sprintf( esc_html('Create a support ticket', 'elixar'), esc_html( $theme_data->Name )); ?></a>
                            </p>
                        </div>
                    </div>
                    <div class="theme_info_right">
                        <img src="<?php echo get_template_directory_uri(); ?>/screenshot.png" alt="Theme Screenshot" />
                    </div>
                </div>
            </div>
        <?php } ?>
        <?php if ( $tab == 'recommended_actions' ) { ?>
            <div class="action-required-tab info-tab-content">
                <?php if ( is_child_theme() ){
                    $child_theme = wp_get_theme();
                    ?>
                    <form method="post" action="<?php echo esc_attr( $current_action_link ); ?>" class="demo-import-boxed copy-settings-form">
                        <p>
                           <strong> <?php /* translators: %s: Child Theme Info */printf( esc_html__(  'You\'re using %1$s theme, It\'s a child theme of Elixar', 'elixar' ) ,  esc_html( $child_theme->Name ) ); ?></strong>
                        </p>
                        <p><?php printf( esc_html__(  "Child theme uses it's own theme setting name, would you like to copy setting data from parent theme to this child theme?", 'elixar' ) ); ?></p>
                        <p>
                        <?php
                        $select = '<select name="copy_from">';
                        $select .= '<option value="">'.esc_html__( 'From Theme', 'elixar' ).'</option>';
                        $select .= '<option value="elixar">Elixar</option>';
                        $select .= '<option value="'.esc_attr( $child_theme->get_stylesheet() ).'">'. esc_html( $child_theme->Name ).'</option>';
                        $select .='</select>';
                        $select_2 = '<select name="copy_to">';
                        $select_2 .= '<option value="">'.esc_html__( 'To Theme', 'elixar' ).'</option>';
                        $select_2 .= '<option value="elixar">Elixar</option>';
                        $select_2 .= '<option value="'.esc_attr( $child_theme->get_stylesheet() ).'">'.esc_html( $child_theme->Name ).'</option>';
                        $select_2 .='</select>';
                        echo $select . ' to '. $select_2;
                        ?>
                        <input type="submit" class="button button-secondary" value="<?php esc_attr_e( 'Copy now', 'elixar' ); ?>">
                        </p>
                        <?php if ( isset( $_GET['copied'] ) && $_GET['copied'] == 1 ) { ?>
                            <p><?php esc_html_e( 'Your settings copied.', 'elixar' ); ?></p>
                        <?php } ?>
                    </form>
                <?php } ?>
                <?php if ( $actions_r['number_active']  > 0 ) { ?>
                    <?php $actions = wp_parse_args( $actions, array( 'page_on_front' => '', 'page_template' ) ) ?>
                    <?php if ( $actions['recommend_plugins'] == 'active' ) {  ?>
                        <div id="plugin-filter" class="recommend-plugins action-required">
                            <a  title="" class="dismiss" href="<?php echo add_query_arg( array( 'elixar_action_notice' => 'recommend_plugins' ), $current_action_link ); ?>">
                                <?php if ( $actions_r['hide_by_click']['recommend_plugins'] == 'hide' ) { ?>
                                    <span class="dashicons dashicons-hidden"></span>
                                <?php } else { ?>
                                    <span class="dashicons  dashicons-visibility"></span>
                                <?php } ?>
                            </a>
                            <h3><?php esc_html_e( 'Recommend Plugins', 'elixar' ); ?></h3>
                            <?php
                            elixar_render_recommend_plugins( $recommend_plugins );
                            ?>
                        </div>
                    <?php } ?>
                    <?php if ( $actions['page_on_front'] == 'active' ) {  ?>
                        <div class="theme_link  action-required">
                            <a title="<?php  esc_attr_e( 'Dismiss', 'elixar' ); ?>" class="dismiss" href="<?php echo add_query_arg( array( 'elixar_action_notice' => 'page_on_front' ), $current_action_link ); ?>">
                                <?php if ( $actions_r['hide_by_click']['page_on_front'] == 'hide' ) { ?>
                                    <span class="dashicons dashicons-hidden"></span>
                                <?php } else { ?>
                                    <span class="dashicons  dashicons-visibility"></span>
                                <?php } ?>
                            </a>
                            <h3><?php esc_html_e( 'Switch "Front page displays" to "A static page"', 'elixar' ); ?></h3>
                            <div class="about">
                                <p><?php esc_html_e( 'In order to have the home page for your website, please go to Customize -&gt; Static Front Page and switch "Front page displays" to "A static page".', 'elixar' ); ?></p>
                            </div>
                            <p>
                                <a  href="<?php echo esc_url(admin_url('options-reading.php')); ?>" class="button"><?php esc_html_e('Setup front page displays', 'elixar'); ?></a>
                            </p>
                        </div>
                    <?php } ?>
                    <?php if ( $actions['page_template'] == 'active' ) {  ?>
                        <div class="theme_link  action-required">
                            <a  title="<?php  esc_attr_e( 'Dismiss', 'elixar' ); ?>" class="dismiss" href="<?php echo add_query_arg( array( 'elixar_action_notice' => 'page_template' ), $current_action_link ); ?>">
                                <?php if ( $actions_r['hide_by_click']['page_template'] == 'hide' ) { ?>
                                    <span class="dashicons dashicons-hidden"></span>
                                <?php } else { ?>
                                    <span class="dashicons  dashicons-visibility"></span>
                                <?php } ?>
                            </a>
                            <h3><?php esc_html_e( 'Set your homepage page template to "Home".', 'elixar' ); ?></h3>
                            <div class="about">
                                <p><?php esc_html_e( 'In order to change homepage section contents, you will need to set template "Home" for your homepage.', 'elixar' ); ?></p>
                            </div>
                            <p>
                                <?php
                                $front_page = get_option( 'page_on_front' );
                                if ( $front_page <= 0  ) {
                                    ?>
                                    <a  href="<?php echo esc_url(admin_url('options-reading.php')); ?>" class="button"><?php esc_html_e('Setup front page displays', 'elixar'); ?></a>
                                    <?php
                                }
                                if ( $front_page > 0 && get_post_meta( $front_page, '_wp_page_template', true ) != 'home-page.php' ) {
                                    ?>
                                    <a href="<?php echo esc_url(get_edit_post_link( $front_page )); ?>" class="button"><?php esc_html_e('Change homepage page template', 'elixar'); ?></a>
                                    <?php
                                }
                                ?>
                            </p>
                        </div>
                    <?php } ?>
                    <?php do_action( 'elixar_more_required_details', $actions ); ?>
                <?php  } else { ?>
                    <h3><?php /* translators: %s: Update Info */
					printf( esc_html__( 'Keep update with %s', 'elixar' ) , esc_html( $theme_data->Name )); ?></h3>
                    <p><?php esc_html_e( 'Hooray! There are no required actions for you right now.', 'elixar' ); ?></p>
                <?php } ?>
            </div>
        <?php } ?>
	    <?php if ( ! class_exists('Elixar_Premium') ) { ?>
	    <?php if ( $tab == 'free_pro' ) { ?>
            <div id="free_pro" class="freepro-tab-content info-tab-content">
                <table class="free-pro-table">
                    <thead><tr><th></th><th><?php esc_html_e('Elixar Free', 'elixar') ?></th><th><?php esc_html_e('Elixar Premium', 'elixar') ?></th></tr></thead>
                    <tbody>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('WooCommerce Support', 'elixar') ?></h4>
                        </td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Hero Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h5><?php esc_html_e('&#45; Background Video', 'elixar') ?></h5>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h5><?php esc_html_e('&#45; Background Slides', 'elixar') ?></h5>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('About Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h5><?php esc_html_e('&#45; Number of items', 'elixar') ?></h5>
                        </td>
                        <td class="only-pro"><span class="dashicons-before "><?php echo esc_html('3'); ?></span></td>
                        <td class="only-lite"><span class="dashicons-before"><?php esc_html_e('Unlimited', 'elixar') ?></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Service Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h5><?php esc_html_e('&#45; Number of items', 'elixar') ?></h5>
                        </td>
                        <td class="only-pro"><span class="dashicons-before "><?php echo esc_html('4'); ?></span></td>
                        <td class="only-lite"><span class="dashicons-before"><?php esc_html_e('Unlimited', 'elixar') ?></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Counter Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Team Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Latest Blog Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Contact Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Drag and drop section orders', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Add New Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Styling for all sections', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Google Map Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Pricing Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Testimonial Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Call To Action Section', 'elixar') ?></h4>
                        </td>
						<td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Projects Section', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('Typography Options', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr>
                        <td>
                            <h4><?php esc_html_e('24/7 Priority Support', 'elixar') ?></h4>
                        </td>
                        <td class="only-pro"><span class="dashicons-before dashicons-no-alt"></span></td>
                        <td class="only-lite"><span class="dashicons-before dashicons-yes"></span></td>
                    </tr>
                    <tr class="ti-about-page-text-center"><td></td><td colspan="2"><a href="<?php echo esc_url('https://www.webhuntinfotech.com/theme/elixar-premium/'); ?>" target="_blank" class="button button-primary button-hero"><?php esc_html_e('Get Elixar Premium now!', 'elixar') ?></a></td></tr>
                    </tbody>
                </table>
            </div>
	    <?php } ?>
	    <?php } ?>
        <?php if ( $tab == 'changelog-viewer' ) { ?>
            <div class="changelog-tab-content info-tab-content">
                <?php
                WP_Filesystem();
                global $wp_filesystem;
                $Elixar_lite_changelog = $wp_filesystem->get_contents( get_template_directory().'/CHANGELOG.md' );
                $Elixar_lite_changelog_lines = explode(PHP_EOL, $Elixar_lite_changelog);
                foreach($Elixar_lite_changelog_lines as $Elixar_lite_changelog_line){
                    if(substr( $Elixar_lite_changelog_line, 0, 3 ) === "###"){
                        echo '<h3>'.esc_html( substr($Elixar_lite_changelog_line,3) ).'</h3>';
                    }else if(substr( $Elixar_lite_changelog_line, 0, 2 ) === "##"){
                        echo '<h4>'.esc_html( substr($Elixar_lite_changelog_line,3) ).'</h4>';
                    } else {
                        echo esc_html( $Elixar_lite_changelog_line),'<br/>';
                    }
                }
                ?>
            </div>
        <?php } ?>
        <?php do_action( 'elixar_more_tabs_details', $actions ); ?>
    </div> <!-- END .theme_info -->
    <script type="text/javascript">
        jQuery(  document).ready( function( $ ){
            $( 'body').addClass( 'about-php' );
            $( '.copy-settings-form').on( 'submit', function(){
                var c = confirm( '<?php echo esc_html_e( 'Are you sure want to copy ?', 'elixar' ); ?>' );
                if ( ! c ) {
                    return false;
                }
            } );
        } );
    </script>
    <?php
}